<?php

namespace Litepie\News\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\News\Http\Requests\NewsCategoryRequest;
use Litepie\News\Interfaces\NewsCategoryRepositoryInterface;
use Litepie\News\Models\NewsCategory;

/**
 * Resource controller class for news_category.
 */
class NewsCategoryResourceController extends BaseController
{

    /**
     * Initialize news_category resource controller.
     *
     * @param type NewsCategoryRepositoryInterface $news_category
     *
     * @return null
     */
    public function __construct(NewsCategoryRepositoryInterface $news_category)
    {
        parent::__construct();
        $this->repository = $news_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\News\Repositories\Criteria\NewsCategoryResourceCriteria::class);
    }

    /**
     * Display a list of news_category.
     *
     * @return Response
     */
    public function index(NewsCategoryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\News\Repositories\Presenter\NewsCategoryPresenter::class)
                ->$function();
        }

        $news_categories = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('news::news_category.names'))
            ->view('news::news_category.index', true)
            ->data(compact('news_categories', 'view'))
            ->output();
    }

    /**
     * Display news_category.
     *
     * @param Request $request
     * @param Model   $news_category
     *
     * @return Response
     */
    public function show(NewsCategoryRequest $request, NewsCategory $news_category)
    {

        if ($news_category->exists) {
            $view = 'news::news_category.show';
        } else {
            $view = 'news::news_category.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('news::news_category.name'))
            ->data(compact('news_category'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new news_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(NewsCategoryRequest $request)
    {

        $news_category = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('news::news_category.name')) 
            ->view('news::news_category.create', true) 
            ->data(compact('news_category'))
            ->output();
    }

    /**
     * Create new news_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(NewsCategoryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $news_category                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('news::news_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('news/news_category/' . $news_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/news/news_category'))
                ->redirect();
        }

    }

    /**
     * Show news_category for editing.
     *
     * @param Request $request
     * @param Model   $news_category
     *
     * @return Response
     */
    public function edit(NewsCategoryRequest $request, NewsCategory $news_category)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('news::news_category.name'))
            ->view('news::news_category.edit', true)
            ->data(compact('news_category'))
            ->output();
    }

    /**
     * Update the news_category.
     *
     * @param Request $request
     * @param Model   $news_category
     *
     * @return Response
     */
    public function update(NewsCategoryRequest $request, NewsCategory $news_category)
    {
        try {
            $attributes = $request->all();

            $news_category->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('news::news_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('news/news_category/' . $news_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('news/news_category/' . $news_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the news_category.
     *
     * @param Model   $news_category
     *
     * @return Response
     */
    public function destroy(NewsCategoryRequest $request, NewsCategory $news_category)
    {
        try {

            $news_category->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('news::news_category.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('news/news_category/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('news/news_category/' . $news_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple news_category.
     *
     * @param Model   $news_category
     *
     * @return Response
     */
    public function delete(NewsCategoryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('news::news_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('news/news_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/news/news_category'))
                ->redirect();
        }

    }

    /**
     * Restore deleted news_categories.
     *
     * @param Model   $news_category
     *
     * @return Response
     */
    public function restore(NewsCategoryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('news::news_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/news/news_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/news/news_category/'))
                ->redirect();
        }

    }

}
